/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of the plugins of the Qt Toolkit.
**
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the either Technology Preview License Agreement or the
** Beta Release License Agreement.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** Qt for Windows(R) Licensees
** As a special exception, Nokia, as the sole copyright holder for Qt
** Designer, grants users of the Qt/Eclipse Integration plug-in the
** right for the Qt/Eclipse Integration to link to functionality
** provided by Qt Designer and its related libraries.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/

#ifndef QDIRECTFBPIXMAP_H
#define QDIRECTFBPIXMAP_H

#include <QtGui/private/qpixmapdata_p.h>
#include <QtGui/private/qpaintengine_raster_p.h>

QT_BEGIN_HEADER

QT_MODULE(Gui)

#include <directfb.h>

class QDirectFBPaintEngine;
class QDirectFBScreen;

class QDirectFBPixmapData : public QPixmapData, QCustomRasterPaintDevice
{
public:
    QDirectFBPixmapData(PixelType pixelType);
    ~QDirectFBPixmapData();

    // Re-implemented from QPixmapData:
    void resize(int width, int height);
    void fromImage(const QImage &image, Qt::ImageConversionFlags flags);
    void copy(const QPixmapData *data, const QRect &rect);
    void fill(const QColor &color);
    bool hasAlphaChannel() const;
    QPixmap transformed(const QTransform &matrix,
                        Qt::TransformationMode mode) const;
    QImage toImage() const;
    QPaintEngine* paintEngine() const;
    QImage *buffer();

    // Re-implemented from QCustomRasterPaintDevice and QPixmapData
    int metric(QPaintDevice::PaintDeviceMetric metric) const;

    // Reimplemented from QCustomRasterPaintDevice:
    void* memory() const;
    QImage::Format format() const;
    int bytesPerLine() const;
    QSize size() const;


    // Class-specific methods:
    IDirectFBSurface* dfbSurface() const { return surface; }
    void unlockDirectFB();

private:
    IDirectFBSurface *surface;
    QDirectFBPaintEngine *engine;
    QImage *image;
    QDirectFBScreen* screen;
};

QT_END_HEADER

#endif // QDIRECTFBPIXMAP_H
